@@ -11,9 +11,9 @@ import (
 	"sort"
 	"strings"
 
-	policiesv1 "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policy/v1"
-	"github.com/open-cluster-management/governance-policy-propagator/pkg/controller/common"
 	"github.com/operator-framework/operator-sdk/pkg/k8sutil"
+	policiesv1 "github.com/stolostron/governance-policy-propagator/pkg/apis/policy/v1"
+	"github.com/stolostron/governance-policy-propagator/pkg/controller/common"
 	corev1 "k8s.io/api/core/v1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
